summaryrefslogtreecommitdiffstats
path: root/kmail/kmsystemtray.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmsystemtray.cpp')
-rw-r--r--kmail/kmsystemtray.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/kmsystemtray.cpp b/kmail/kmsystemtray.cpp
index 1eb9f467..2a3bd975 100644
--- a/kmail/kmsystemtray.cpp
+++ b/kmail/kmsystemtray.cpp
@@ -218,7 +218,7 @@ void KMSystemTray::updateCount()
// "This function is slow because it involves transformation to a TQImage,
// non-trivial computations and a transformation back to a TQBitmap."). Then
// I have to convert the resulting TQPixmap to a TQImage in order to overlay
// the light KMail icon with the number (because KIconEffect::overlay only
// works with TQImage). Finally the resulting TQImage has to be converted
// back to a TQPixmap.
// That's a lot of work for overlaying the KMail icon with the number of
@@ -235,7 +235,7 @@ void KMSystemTray::updateCount()
// Overlay the light KMail icon with the number image
TQImage iconWithNumberImage = mLightIconImage.copy();
- KIconEffect::overlay( iconWithNumberImage, numberImage );
+ TDEIconEffect::overlay( iconWithNumberImage, numberImage );
TQPixmap iconWithNumber;
iconWithNumber.convertFromImage( iconWithNumberImage );
@@ -218,7 +218,7 @@ void KMSystemTray::updateCount()
// non-trivial computations and a transformation back to a TQBitmap."). Then
// I have to convert the resulting TQPixmap to a TQImage in order to overlay
- // the light KMail icon with the number (because KIconEffect::overlay only
+ // the light KMail icon with the number (because TDEIconEffect::overlay only
// works with TQImage). Finally the resulting TQImage has to be converted
// back to a TQPixmap.